==> nextcloud-29.0.12.zip: nextcloud/apps/circles/l10n/fr.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Équipes",
    "You created the team {circle}" : "Vous avez créé l'équipe {circle}",
    "{author} created the team {circle}" : "{author} a créé l'équipe {circle}",
    "You deleted {circle}" : "Vous avez supprimé {circle}",
    "{author} deleted {circle}" : "{author} a supprimé {circle}",
    "You made {member} join {circle}" : "Vous avez fait rejoindre {circle} à {member}",
    "{author} made {member} join {circle}" : "{author} a fait rejoindre {circle} à {member}",
    "You added team {member} as member to {circle}" : "Vous avez ajouté l'équipe {member} comme membre de {circle}",
    "{author} added team {member} as member to {circle}" : "{author} à ajoutée {member} des l'équipe en tant que membre à {circle}",
    "You made {member} leave {circle}" : "Vous avez fait quitter {circle} à {member}",
    "{author} made {member} leave {circle}" : "{author} a fait quitter {circle} à {member}",
    "You removed {member} from {circle}" : "Vous avez supprimé {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} à retirer {member} de {circle}",
    "You joined {circle}" : "Vous avez rejoint {circle}",
    "{member} joined {circle}" : "{member} a rejoint {circle}",
    "You accepted the invitation to join {circle}" : "Vous avez accepté l'invitation pour rejoindre {circle}",
    "{member} accepted the invitation to join {circle}" : "[member] a accepté l'invitation pour rejoindre [circle}",
    "You added {member} as member to {circle}" : "Vous avez ajouté {member} comme membre de {circle}",
    "You have been added as member to {circle} by {author}" : "Vous avez été ajouté comme membre de {circle} par {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a été ajouté comme membre de {circle} par {author}",
    "You added {external} to {circle}" : "Vous avez ajouté {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a été ajouté à {circle} par {author}",
    "You accepted {member}'s request to join {circle}" : "Vous avez accepté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Votre demande pour rejoindre {circle} a été acceptée par {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La demande de {member} pour rejoindre {circle} a été acceptée par {author}",
    "You left {circle}" : "Vous quittez {circle}",
    "{member} left {circle}" : "{member} a quitté {circle}",
    "You declined the invitation to join {circle}" : "Vous avez refusé l'invitation à rejoindre {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a refusé l'invitation à rejoindre {circle}",
    "You cancelled your request to join {circle}" : "Vous avez annulé la demande pour rejoindre {circle}",
    "{member} cancelled a request to join {circle}" : "{member} a annulé sa demande pour rejoindre {circle}",
    "You have been removed from {circle} by {author}" : "Vous avez été retiré de {circle} par {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a été retiré de {circle} par {author}",
    "You removed {external} from {circle}" : "Vous avez retiré {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a été retiré de {circle} par {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Vous avez annulé l'invitation de {member} à rejoindre {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Votre invitation à rejoindre {circle} a été annulé par {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a annulé l'invitation de {member} à rejoindre {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vous avez rejeté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Votre demande pour rejoindre {circle} a été rejetée par {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La demande de {member} de rejoindre {circle} a été rejetée par {author}",
    "You invited {member} to join {circle}" : "Vous avez invité {member} à rejoindre {circle}",
    "You have been invited to join {circle} by {author}" : "Vous avez été invité à rejoindre {circle} par {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a été invité à rejoindre {circle} par {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Vous avez changé le niveau de {member} dans {circle} à %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a changé votre niveau dans {circle} à %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a changé le niveau de {member} dans {circle} à %1$s",
    "You sent a request to join {circle}" : "Vous avez envoyé une demande pour rejoindre {circle}",
    "{member} sent a request to join {circle}" : "{member} a envoyé une demande pour rejoindre {circle}",
    "You are the new owner of {circle}" : "Vous êtes le nouveau propriétaire de {circle}",
    "{member} is the new owner of {circle}" : "{member} est le nouveau propriétaire de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sur les événements survenant dans une <strong>équipe</strong> dont vous êtes membre",
    "Any important event in a <strong>team</strong> you are moderating" : "Tous les événements importants dans une <strong>équipe</strong> que vous modérez",
    "On global events happening in any <strong>team</strong>" : "Sur les événements globaux survenant dans n’importe quelle <strong>équipe</strong>",
    "Shared to Circles" : "Partagé avec les cercles",
    "Single" : "Simple",
    "Personal" : "Personnel",
    "System" : "Système",
    "Visible" : "Visible",
    "Open" : "Ouvert",
    "Invite" : "Inviter",
    "Join request" : "Demande d'adhésion",
    "Friends" : "Amis",
    "Password protected" : "Protégé par mot de passe",
    "No Owner" : "Pas de propriétaire",
    "Hidden" : "Caché",
    "Backend" : "Infrastructure",
    "Local" : "Local",
    "Root" : "Racine",
    "Team invite" : "Invitation d'équipe",
    "Federated" : "Fédéré",
    "Mount point" : "Point de montage",
    "Nextcloud Account" : "Compte Nextcloud",
    "Nextcloud Group" : "Groupe Nextcloud",
    "Email address" : "Adresse e-mail",
    "Contact" : "Contact",
    "Circle" : "Cercle",
    "Nextcloud App" : "App Nextcloud",
    "Member" : "Membre",
    "Moderator" : "Modérateur",
    "Admin" : "Administrateur",
    "Owner" : "Propriétaire",
    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
    "%s shared »%s« with \"%s\"." : "%s a partagé »%s« avec « %s ».",
    "%s on %s" : "%s sur %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé »%2$s« avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partagé »%2$s« avec vous. Vous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.",
    "Password to access »%1$s« shared to you by %2$s" : "Mot de passe pour accéder à «%1$s» partagé avec vous par %2$s",
    "Password to access »%s«" : "Mot de passe pour accéder à «%s»",
    "It is protected with the following password:" : "Protégé par le mot de passe suivant :",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir.",
    "Open »%s«" : "Ouvrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partagé plusieurs fichiers avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sa partagé plusieurs fichiers avec vous. Vous devriez déjà avoir reçu un courrier avec un lien pour y accéder.",
    "Password to access files shared to you by %1$s" : "Mot de passe pour accéder aux fichiers partagés avec vous par %1$s",
    "Password to access files" : "Mot de passe pour accéder aux fichiers",
    "%s shared multiple files with \"%s\"." : "%s a partagé plusieurs fichiers avec « %s ».",
    "%s shared multiple files with you." : "%s a partagé plusieurs fichiers avec vous.",
    "Boot up" : "Démarrage",
    "Nextcloud Initialization" : "Initialisation de Nexctcloud",
    "Circles App Initialization" : "Initialisation de l'application Cercles",
    "Fresh installation status" : "Statut de l'installation",
    "Building Local Database" : "Construction de la base de données locale",
    "Testing Basic Circle Creation" : "Test de création d'un cercle basique",
    "Adding local users and moderators" : "Ajout d'utilisateurs locaux et de modérateurs",
    "Show all teams" : "Afficher toutes les équipes",
    "Create a new team" : "Créer une nouvelle équipe",
    "Files" : "Fichiers",
    "This feature is not available for personal circles" : "Cette fonctionnalité n'est pas disponible pour les cercles personnels",
    "The team is not federated" : "L'équipe n'est pas fédérée",
    "You cannot join this team" : "Vous ne pouvez pas rejoindre cette équipe",
    "This member is not a moderator" : "Ce membre n’est pas modérateur",
    "Insufficient privileges" : "Privilèges insuffisants",
    "This member does not exist" : "Ce membre n’existe pas",
    "This member is the owner of the team" : "Ce membre est le propriétaire de l'équipe",
    "Level cannot be changed for this type of member" : "Le niveau ne peut pas être modifié pour ce type de membre",
    "You are already a member of this circle" : "Vous êtes déjà membre du cercle",
    "You have been blocked from this circle" : "Vous avez été bloqué de ce cercle",
    "The account is already a member of this circle" : "Le compte est déjà membre de ce cercle",
    "The account has already been invited into this circle" : "Le compte a déjà été invité à participer à ce cercle",
    "%s (Team owned by %s)" : "%s (%s est propriétaire de l'équipe)",
    "You are now a member of the Team \"%2$s\"" : "Vous êtes désormais membre de l'équipe \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Vous avez été invité par %1$s dans l'équipe \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s a envoyé une demande pour être membre de l'équipe \"%2$s\"",
    "Accept" : "Accepter",
    "Refuse" : "Refuser",
    "Leave the team" : "Quitter l'équipe",
    "%s" : "%s",
    "Personal team" : "Équipe personnelle",
    "%s owned by %s" : "%s appartenant à %s",
    "You have no permission to create a new team" : "Vous n'avez pas l'autorisation de créer une nouvelle équipe",
    "%s shared a file with \"%s\"." : "%s a partagé un fichier avec « %s ».",
    "%s shared a file with you." : "%s a partagé un fichier avec vous.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé quelque chose avec vous.\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partagé quelque chose avec vous.\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder.",
    "Password to access content shared with you by %1$s" : "Mot de passe pour accéder au contenu partagé avec vous par %1$s",
    "Password to access content" : "Mot de passe pour accéder au contenu",
    "This item is already shared with this team" : "Cet objet est déjà partagé avec cette équipe",
    "Bring cloud-users closer together." : "Permet de rapprocher les utilisateur du cloud ensemble ",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "L'application « Équipes » permet aux personnes de créer leurs propres groupes de personnes / collègues / amis\nCes groupes de personnes peuvent alors être utilisés par toutes les autres applications à des fins de partage.",
    "No files in here" : "Aucun fichier",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "Teams' files" : "Fichiers de l'équipe",
    "Select team to filter by" : "Sélectionner l'équipe à filtrer",
    "No teams found" : "Aucune équipe trouvée",
    "Please select teams to filter by" : "Veuillez sélectionner les équipes à filtrer",
    "No files found for the selected teams" : "Aucun fichier trouvé pour les équipes sélectionnées",
    "{author} added team {member} has been added as member to {circle}" : "{author} a ajoutée {member} à l'équipe et a été ajouté en tant que membre à {circle}",
    "You are now a member of the Circle \"%2$s\"" : "Vous êtes maintenant membre du cercle « %2$s »",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vous avez été invité par %1$s dans le cercle « %2$s »",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s a demandé à être membre du cercle « %2$s »",
    "Leave the circle" : "Quitter le cercle"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.6rc1.zip: nextcloud/apps/circles/l10n/fr.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Vous avez créé l'équipe {circle}",
    "{author} created the team {circle}" : "{author} a créé l'équipe {circle}",
    "You deleted {circle}" : "Vous avez supprimé {circle}",
    "{author} deleted {circle}" : "{author} a supprimé {circle}",
    "You made {member} join {circle}" : "Vous avez fait rejoindre {circle} à {member}",
    "{author} made {member} join {circle}" : "{author} a fait rejoindre {circle} à {member}",
    "You added team {member} as member to {circle}" : "Vous avez ajouté l'équipe {member} comme membre de {circle}",
    "{author} added team {member} as member to {circle}" : "{author} a ajouté {member} en tant que membre de l'équipe {circle}",
    "You made {member} leave {circle}" : "Vous avez fait quitter {circle} à {member}",
    "{author} made {member} leave {circle}" : "{author} a fait quitter {circle} à {member}",
    "You removed {member} from {circle}" : "Vous avez supprimé {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} à retirer {member} de {circle}",
    "You joined {circle}" : "Vous avez rejoint {circle}",
    "{member} joined {circle}" : "{member} a rejoint {circle}",
    "You accepted the invitation to join {circle}" : "Vous avez accepté l'invitation pour rejoindre {circle}",
    "{member} accepted the invitation to join {circle}" : "{member}a accepté l'invitation pour rejoindre {circle}",
    "You added {member} as member to {circle}" : "Vous avez ajouté {member} comme membre de {circle}",
    "You have been added as member to {circle} by {author}" : "Vous avez été ajouté·e comme membre de {circle} par {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a été ajouté comme membre de {circle} par {author}",
    "You added {external} to {circle}" : "Vous avez ajouté {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a été ajouté à {circle} par {author}",
    "You accepted {member}'s request to join {circle}" : "Vous avez accepté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Votre demande pour rejoindre {circle} a été acceptée par {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La demande de {member} pour rejoindre {circle} a été acceptée par {author}",
    "You left {circle}" : "Vous quittez {circle}",
    "{member} left {circle}" : "{member} a quitté {circle}",
    "You declined the invitation to join {circle}" : "Vous avez refusé l'invitation à rejoindre {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a refusé l'invitation à rejoindre {circle}",
    "You cancelled your request to join {circle}" : "Vous avez annulé la demande pour rejoindre {circle}",
    "{member} cancelled a request to join {circle}" : "{member} a annulé sa demande pour rejoindre {circle}",
    "You have been removed from {circle} by {author}" : "Vous avez été retiré·e de {circle} par {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a été retiré de {circle} par {author}",
    "You removed {external} from {circle}" : "Vous avez retiré {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a été retiré de {circle} par {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Vous avez annulé l'invitation de {member} à rejoindre {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Votre invitation à rejoindre {circle} a été annulé par {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a annulé l'invitation de {member} à rejoindre {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vous avez rejeté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Votre demande pour rejoindre {circle} a été rejetée par {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La demande de {member} de rejoindre {circle} a été rejetée par {author}",
    "You invited {member} to join {circle}" : "Vous avez invité {member} à rejoindre {circle}",
    "You have been invited to join {circle} by {author}" : "Vous avez été invité·e à rejoindre {circle} par {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a été invité à rejoindre {circle} par {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Vous avez changé le niveau de {member} dans {circle} à %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a changé votre niveau dans {circle} à %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a changé le niveau de {member} dans {circle} à %1$s",
    "You sent a request to join {circle}" : "Vous avez envoyé une demande pour rejoindre {circle}",
    "{member} sent a request to join {circle}" : "{member} a envoyé une demande pour rejoindre {circle}",
    "You are the new owner of {circle}" : "Vous êtes le nouveau propriétaire de {circle}",
    "{member} is the new owner of {circle}" : "{member} est le nouveau propriétaire de {circle}",
    "Teams" : "Équipes",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sur les événements survenant dans une <strong>équipe</strong> dont vous êtes membre",
    "Any important event in a <strong>team</strong> you are moderating" : "Tous les événements importants dans une <strong>équipe</strong> que vous modérez",
    "On global events happening in any <strong>team</strong>" : "Sur les événements globaux survenant dans n’importe quelle <strong>équipe</strong>",
    "Single" : "Simple",
    "Personal" : "Personnel",
    "System" : "Système",
    "Visible" : "Visible",
    "Open" : "Ouvert",
    "Invite" : "Inviter",
    "Join request" : "Demande d'adhésion",
    "Friends" : "Amis",
    "Password protected" : "Protégé par mot de passe",
    "No Owner" : "Pas de propriétaire",
    "Hidden" : "Caché",
    "Backend" : "Infrastructure",
    "Local" : "Local",
    "Root" : "Racine",
    "Team invite" : "Invitation d'équipe",
    "Federated" : "Fédéré",
    "Mount point" : "Point de montage",
    "Nextcloud Account" : "Compte Nextcloud",
    "Nextcloud Group" : "Groupe Nextcloud",
    "Email address" : "Adresse e-mail",
    "Contact" : "Contact",
    "Team" : "Équipe",
    "Nextcloud App" : "App Nextcloud",
    "Teams App" : "Application Équipes",
    "Admin Command Line" : "Ligne de commande Administrateur",
    "Member" : "Membre",
    "Moderator" : "Modérateur",
    "Admin" : "Administrateur",
    "Owner" : "Propriétaire",
    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
    "%s shared »%s« with \"%s\"." : "%s a partagé »%s« avec « %s ».",
    "%s on %s" : "%s sur %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé »%2$s« avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partagé »%2$s« avec vous. Vous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.",
    "Password to access »%1$s« shared to you by %2$s" : "Mot de passe pour accéder à «%1$s» partagé avec vous par %2$s",
    "Password to access »%s«" : "Mot de passe pour accéder à «%s»",
    "It is protected with the following password:" : "Protégé par le mot de passe suivant :",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir.",
    "Open »%s«" : "Ouvrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partagé plusieurs fichiers avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sa partagé plusieurs fichiers avec vous. Vous devriez déjà avoir reçu un courrier avec un lien pour y accéder.",
    "Password to access files shared to you by %1$s" : "Mot de passe pour accéder aux fichiers partagés avec vous par %1$s",
    "Password to access files" : "Mot de passe pour accéder aux fichiers",
    "%s shared multiple files with \"%s\"." : "%s a partagé plusieurs fichiers avec « %s ».",
    "%s shared multiple files with you." : "%s a partagé plusieurs fichiers avec vous.",
    "Boot up" : "Démarrage",
    "Nextcloud Initialization" : "Initialisation de Nexctcloud",
    "Circles App Initialization" : "Initialisation de l'application Cercles",
    "Fresh installation status" : "Statut de l'installation",
    "Building Local Database" : "Construction de la base de données locale",
    "Testing Basic Team Creation" : "Test de création d'une Équipe basique",
    "Adding local users and moderators" : "Ajout d'utilisateurs locaux et de modérateurs",
    "Show all teams" : "Afficher toutes les équipes",
    "Create a new team" : "Créer une nouvelle équipe",
    "Files" : "Fichiers",
    "This feature is not available for personal teams" : "Cette fonctionnalité n'est pas disponible pour les Équipes personnelles",
    "The team is not federated" : "L'équipe n'est pas fédérée",
    "You cannot join this team" : "Vous ne pouvez pas rejoindre cette équipe",
    "This member is not a moderator" : "Ce membre n’est pas modérateur",
    "Insufficient privileges" : "Privilèges insuffisants",
    "This member does not exist" : "Ce membre n’existe pas",
    "This member is the owner of the team" : "Ce membre est le propriétaire de l'équipe",
    "Level cannot be changed for this type of member" : "Le niveau ne peut pas être modifié pour ce type de membre",
    "You are already a member of this team" : "Vous êtes déjà membre de cette Équipe",
    "You have been blocked from this team" : "Vous êtes bloqué(e) de cette Équipe",
    "The account is already a member of this team" : "Le compte est déjà membre de cette Équipe",
    "The account has already been invited into this team" : "Le compte a déjà été invité à participer à cette Équipe",
    "%s (Team owned by %s)" : "%s (%s est propriétaire de l'équipe)",
    "You are now a member of the Team \"%2$s\"" : "Vous êtes désormais membre de l'équipe \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Vous avez été invité·e par %1$s dans l'équipe \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s a envoyé une demande pour être membre de l'équipe \"%2$s\"",
    "Accept" : "Accepter",
    "Refuse" : "Refuser",
    "Leave the team" : "Quitter l'équipe",
    "%s" : "%s",
    "Personal team" : "Équipe personnelle",
    "%s owned by %s" : "%s appartenant à %s",
    "You have no permission to create a new team" : "Vous n'avez pas l'autorisation de créer une nouvelle équipe",
    "%s shared a file with \"%s\"." : "%s a partagé un fichier avec « %s ».",
    "%s shared a file with you." : "%s a partagé un fichier avec vous.",
    "%1$s shared %2$s with %3$s" : "%1$s a partagé %2$s avec %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s a partagé %2$s avec \"%3$s\"",
    "Open %s" : "Ouvrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé quelque chose avec vous.\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partagé quelque chose avec vous.\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder.",
    "Password to access content shared with you by %1$s" : "Mot de passe pour accéder au contenu partagé avec vous par %1$s",
    "Password to access content" : "Mot de passe pour accéder au contenu",
    "This item is already shared with this team" : "Cet élément est déjà partagé avec cette équipe",
    "Bring cloud-users closer together." : "Permet de rapprocher les utilisateur du cloud ensemble ",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "L'application « Équipes » permet aux personnes de créer leurs propres groupes de personnes / collègues / amis.\nCes groupes de personnes peuvent alors être utilisés par toutes les autres applications à des fins de partage.",
    "https://…" : "https://…",
    "Failed to load teams" : "Impossible de charger les équipes",
    "Try again" : "Réessayer",
    "No teams found" : "Aucune équipe trouvée",
    "Join or create teams to see them here." : "Rejoignez ou créez des équipes pour les voir ici.",
    "Create your first team" : "Créez votre première équipe",
    "Loading…" : "Chargement…",
    "More teams" : "Davantage d'équipes",
    "No files in here" : "Aucun fichier",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "Shared to Circles" : "Partagé avec les cercles"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
